@@ -2,7 +2,7 @@
  library.dynam("libamtrack", pkg, lib)
 }
 .onAttach <- function(lib, pkg){
- packageStartupMessage("This is libamtrack 0.5.4 'Yellow Wombat' (2013-01-22).\nType '?libamtrack' for help.\n")
+ packageStartupMessage("This is libamtrack 0.5.5 'Violet Wombat' (Development, 1289:1290M, 2014-07-07 16:51:49).\nType '?libamtrack' for help.\n")
 }
 .onUnload <- function(libpath){
  try(library.dynam.unload("libamtrack", libpath))
